@@ -1,16 +1,15 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2023-2024 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Sublike::Extended;
-our $VERSION = '0.23_002'; # because package NAME VER doesn't work with _
+package Sublike::Extended 0.19;
 
 use v5.14;
 use warnings;
 
 require XSLoader;
-XSLoader::load( __PACKAGE__, $VERSION );
+XSLoader::load( __PACKAGE__, our $VERSION );
 
 =head1 NAME
 
@@ -18,8 +17,6 @@ C<Sublike::Extended> - enable extended features when parsing C<sub>-like syntax
 
 =head1 SYNOPSIS
 
-=for highlighter language=perl
-
    use v5.26;
    use Sublike::Extended;
    use experimental 'signatures';
@@ -43,12 +40,12 @@ versions of Perl.
 
 =head2 Named parameters
 
-Extended subroutines can declare named parameters in the signature, after any
-positional ones. These take the form of a name prefixed by a colon character.
-The caller of such a function should pass values for these parameters by the
-usual name-value pair syntax that would be used for passing into a regular
-hash. Within the body of the subroutine the values passed into these are
-unpacked into regular lexical variables.
+Extended subroutines can be declare named parameters in the signature, after
+any positional ones. These take the form of a name prefixed by a colon
+character. The caller of such a function should pass values for these
+parameters by the usual name-value pair syntax that would be used for passing
+into a regular hash. Within the body of the subroutine the values passed into
+these are unpacked into regular lexical variables.
 
    extended sub colour (:$red, :$green, :$blue) {
       ... # $red, $green and $blue are available as regular lexicals
@@ -57,40 +54,20 @@ unpacked into regular lexical variables.
    # argument order at the caller site is not important
    colour(green => 1, blue => 2, red => 3);
 
-Positional parameters I<can> be placed after optional positional ones, but in
-order to make use of them the caller would have to pass a value for every
-positional parameter including the optional ones first. This is unlikely to be
-very useful; if you want to have optional parameters and named parameters, use
-named optional ones after any I<mandatory> positional parameters.
-
 As with positional parameters, they are normally mandatory, but can be made
 optional by supplying a defaulting expression. If the caller fails to pass a
-value corresponding to an optional parameter, the default expression is
-evaluated and used instead.
+value corresponding to the parameter, the default expression is evaluated and
+used instead.
 
    extended sub f (:$x0, :$x1, :$x2 = 0) { ... }
    # The caller must provide x0 and x1, but x2 is optional
 
-I<Since version 0.23> named parameters can be given defaulting expressions
-with the C<//=> or C<||=> operators, meaning their defaults apply also if the
-caller passed a present-but-undef, or present-but-false value.
-
-   extended sub f (:$x0, :$x1, :$x2 //= 0) { ... }
-   # $x2 will be set to 0 even if the caller passes  x2 => undef
-
-An optional slurpy hash or (I<since version 0.24>) slurpy array is also
-permitted after all of these. It will contain the values of any other
-name-value pairs given by the caller, after those corresponding to named
-parameters have already been extracted.
+An optional slurpy hash is also permitted after all of these. It will contain
+the values of any other name-value pairs given by the caller, after those
+corresponding to named parameters have already been extracted.
 
    extended sub g (:$alpha, :$beta, %rest) { ... }
 
-   extended sub g (:$alpha, :$beta, @rest) { ... }
-
-In the case of a slurpy array, it will contain every argument value that was
-not consumed as a named parameter pair, in the original order passed by the
-caller, including any duplicates.
-
 =head2 Parameter Attributes
 
 Parameters to extended subroutines can use attribute syntax to apply extra
@@ -119,7 +96,7 @@ C<async> from L<Future::AsyncAwait>
 
    async extended sub f (:$param) { ... }
 
-This can also be used with other keywords that provide C<sub>-like syntax,
+This can also be used with other keywords that provide C<sub->-like syntax,
 such as C<method> from L<Object::Pad> or the core C<use feature 'class'>.
 
    extended method f (:$param) { ... }
@@ -136,17 +113,6 @@ sub unimport
    delete $^H{"Sublike::Extended/extended"};
 }
 
-=head1 TODO
-
-=over 4
-
-=item *
-
-Support defined-or and true-or positional parameters even on versions of Perl
-before they were officially added (v5.38).
-
-=back
-
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
